@@ -116,10 +116,17 @@ def verify_answer(problem):
         try:
             if output[-1] == '\n':
                 output = output[:-1]
+
+            # If there is still a newline, the output is multilined. Print the
+            # first line of the output on a separate line from the "checking
+            # against solution" message.
+            if '\n' in output:
+                output = '\n' + output
+
         except IndexError:
             output = "[no output]"
 
-        is_correct = output == solution
+        is_correct = output.strip() == solution
         click.secho(
             output, bold=True, nl=False, fg=('green' if is_correct else 'red')
         )
